Description Usage Arguments Details Value Note Author(s) References See Also Examples
Sets all the options needed and created an object to give to shout.
1 | shout_settings(username, password=NULL, recipient=NULL, server=NULL,test.message="This is a test of RXMPP.")
|
username |
Username to send the message from. |
password |
Password of the sending account, if not supplied will prompt (see details below). |
test.message |
Message sent to test the connection during setup. If NULL no message is send, defaults to |
recipient |
Address to send the message to, defaults to username. |
server |
Currently unused. |
User is expected to supply at least username which should be a valid JID. In this case messages are send back to username.
If no password is supplied then the user is prompted for one (Mac and Linux only).
test.message is sent to make sure that the options are correct.
A list of all the above information.
Special thanks to Will Thompson and the wocky team.
David Lawrence Miller
XMPP standards foundation http://xmpp.org/.
1 2 | ### Not run
conn_settings<-shout_settings("me@example.com")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.